import org.graphstream.graph.Edge;
import org.graphstream.graph.Graph;
import org.graphstream.graph.Node;
import org.graphstream.graph.implementations.MultiGraph;
import org.graphstream.graph.implementations.SingleGraph;
import org.graphstream.stream.GraphParseException;

import java.io.IOException;

public class TestMaxFlow {

    public static void main(String[] args) throws IOException, GraphParseException {
        /*************** Initialsation du graphe  ****************/
        Graph g = new SingleGraph("test");
        g.addNode("A");
        g.addNode("1");
        g.addNode("2");
        g.addNode("I");
        g.addEdge("e1", "A", "1", true).addAttribute("cap", 10);
        g.addEdge("e2", "A", "2", true).addAttribute("cap", 10);
        g.addEdge("e3", "1", "2", true).addAttribute("cap", 5);
        g.addEdge("e4", "1", "I", true).addAttribute("cap", 8);
        g.addEdge("e5", "2", "I", true).addAttribute("cap", 7);

        g = new SingleGraph("test2"); // initialisation du graphe
        //g.read("Ex1.dgs"); // Un un exemple de graphe

        /* Initialisation du graphe représentatnt le réseau routier*/
        g = new SingleGraph("Reseau");

        // On lu le fichier Reseau.dgs qui représente le graphe
        g.read("Reseau.dgs");
        // for each sur chaque noeud du graphe, on lui donne une coloration vert
        for (Node n : g) {
            n.setAttribute("ui.label", n.getId());
            n.setAttribute("ui.style", "size: 23px; fill-color: green;");
        }
        // affichage du graphe
        g.display(false);

        // instatiation de la classe MaxFlow ---> mf
        MaxFlow mf = new MaxFlow();
        mf.setCapacityAttribute("cap");  // capacité des arétes
        mf.init(g);
        mf.setSource(g.getNode("A"));// source
        mf.setSink(g.getNode("I"));// puit
        mf.compute();

        System.out.println(mf.getFlow());// Affichage du flot
        for (Edge e : g.getEachEdge()) { // pour chaque aretes, on on recupère son flot et sa capacité
            double flow = mf.getFlow(e);
            double cap = mf.getCapacity(e);
            //on affiche le flot sur la capacité
            if (flow > 0) e.addAttribute("ui.label", flow + " / " + cap);
            // si l'arete est saturé, on lui donne une couleur rouge
            if (cap == flow) e.addAttribute("ui.style", "fill-color: red;");
        }
        //afficheGEcart();
    }

    /* methode affichant le graphe écart*/
    /*
    private static void afficheGEcart() throws IOException, GraphParseException {
        Graph g_Ecart = new MultiGraph("Graph_Ecart");
        g_Ecart.read("Graph_Ecart.dgs"); // lecture du fichier Graph_Ecart.dgs représentant le graphe ecart
        for (int i = 0; i < g_Ecart.getEdgeCount(); i++) { // boucle allant de 0 au nombre de noeud
            Edge e = g_Ecart.getEdge(i); // on met dans e l'arc i du graphe ecart, i variant de 0 au nombre total d'arc - 1
            if (e.hasAttribute("toColor")) // si e a pour attribue toColor dans Graph_Ecart.dgs
                e.setAttribute("ui.style", "fill-color: red;");//on change sa couleur en rouge
        }
        g_Ecart.setAttribute("ui.stylesheet", "node {size: 23px;fill-color: green;}");// on change la taille et la couleur en vert
        for (Node n : g_Ecart) { //pour chanque noeud dans dans notre graphe écart
            n.setAttribute("ui.label", n.getId()); // on modifie l'attribue du noeud en son identifiant
        }
        g_Ecart.display(false); // on affiche le graphe écart
    }
  **/

}